<?php

/*
Widget Name: U of U Count Up Widget
Description: Display a count up widget on any page.
Author: Brian Thurber, James Tombs
Author URI: https://umc.utah.edu
*/

class UU_Count_Up_Widget extends SiteOrigin_Widget
{
    private $widgets_code = [];

    public function __construct()
    {
        $text_domain = 'uu-count-up-widget-text-domain';
        parent::__construct(
            'uu-count-up-widget',
            __('U of U Count Up Widget', $text_domain),
            array(
                'description' => __('Display a counter widget on any page.', $text_domain),
            ),
            array(

            ),
            //form options
            array(
                'uu_count_up_high_number' => array(
                    'type' => 'number',
                    'label' => __('Enter a high number', $text_domain),
                ),
                'uu_count_up_low_number' => array(
                    'type' => 'number',
                    'label' => __('Enter a low number', $text_domain),
                ),
                'uu_count_up_reverse' => array(
                    'type' => 'checkbox',
                    'label' => __('Count down from high number?', $text_domain),
                    'default' => false
                ),
                'uu_count_up_color' => array(
                    'type' => 'color',
                    'label' => __('Choose a color', $text_domain),
                    'default' => '#CC0000'
                ),
                'uu_count_up_text_size' => array(
                    'type' => 'slider',
                    'label' => __('Text size(px)', $text_domain),
                    'default' => 24,
                    'min' => 16,
                    'max' => 150,
                    'step' => 1,
                    'integer' => true
                ),
                'uu_count_up_text_align' => array(
                    'type' => 'select',
                    'label' => __('Text Align', $text_domain),
                    'default' => 'center',
                    'options' => array(
                        'center' => __('Center', $text_domain),
                        'left' => __('Left', $text_domain),
                        'right' => __('Right', $text_domain),
                    )
                )
            ),
            plugin_dir_path(__FILE__)
        );

        add_action('wp_footer', function () {
            if ($this->widgets_code) {
                $js = [];
                foreach ($this->widgets_code as $instance) {
                    $js[] = [
                        'uuCountHighNum'  => $instance['uu_count_up_high_number'],
                        'uuCountLowNum'   => $instance['uu_count_up_low_number'],
                        'uuCountReverse'  => $instance['uu_count_up_reverse'],
                        'uuCountColor'    => $instance['uu_count_up_color'],
                        'uuCountTextSize' => $instance['uu_count_up_text_size'],
                        'uuCountTextAlign' => $instance['uu_count_up_text_align'],
                        'widget_id'       => '#uu-count-up-' . $instance['_sow_form_id']
                    ];
                }
                echo '<script>var uuCountUpJs = '.json_encode($js).'</script>';
            }
        });
    }


    public function get_template_name($instance)
    {
        add_action('siteorigin_widgets_after_widget_uu-count-up-widget', function ($instance) {
            $this->widgets_code[$instance['_sow_form_id']] = $instance;
        }, 10, 2);
        return 'uu-count-up-widget-template';
    }



    public function initialize()
    {
        $this->register_frontend_scripts(
            array(
                array( 'countup-js-scripts',
                    plugin_dir_url(__FILE__) . 'js/vendor/countUp.min.js',
                    array( 'jquery' ),
                     '1.0',
                     true
                ),
                array( 'uu-count-up-widget-scripts',
                    plugin_dir_url(__FILE__) . '/js/uu-count-up-widget.js',
                    array( 'jquery' ),
                     '1.0',
                     true
                )
            )
        );
        $this->register_frontend_styles(
            array(
                array(
                    'uu-count-up-widget-styles',
                    plugin_dir_url(__FILE__) . '/css/uu-count-up-widget.css',
                    array(),
                    '1.0'
                ),
            )
        );
    }
}

siteorigin_widget_register('uu-count-up-widget', __FILE__, 'UU_Count_Up_Widget');
