<?php

/*
Widget Name: U of U Donut Chart Widget
Description: Display an informational chart on any page.
Author: Brian Thurber
Author URI: https://umc.utah.edu
*/

class uu_donut_chart_Widget extends SiteOrigin_Widget {

    private $widgets_code = [];

	function __construct() {
		$text_domain = 'uu-donut-chart-widget-text-domain';
		parent::__construct(
			'uu-donut-chart-widget',
			__('U of U Donut Chart Widget', $text_domain),
			array(
				'description' => __('Display a line chart on any page.', $text_domain),
			),
			array(

			),
			//form options
			array(
				// Pie Or Donut
				'uu_donut_chart_pie_or_donut' => array(
					'type' => 'radio',
					'label' => __( 'Pie or Donut Chart?', $text_domain ),
					'default' => 'pie',
					'options' => array(
						'pie' => __( 'Pie', $text_domain ),
						'donut' => __( 'Donut', $text_domain )
					),
					'state_emitter' => array(
						'callback' => 'select',
						'args' => array( 'uu_donut_chart_pie_or_donut' )
					),
				),

				'uu_donut_chart_color_options_radio' => array(
					'type' => 'radio',
					'label' => __( 'Complete color theme or monochrome based on single color?', $text_domain ),
					'default' => 'monochrome',
					'options' => array(
						'color_theme' => __( 'Color Theme', $text_domain ),
						'monochrome' => __( 'Monochrome', $text_domain )
					),
					'state_emitter' => array(
						'callback' => 'select',
						'args' => array( 'uu_donut_chart_color_options_radio' )
					),
				),

				'uu_donut_chart_color_theme' => array(
			        'type' => 'select',
			        'label' => __( 'Chart Type', $text_domain ),
					'default' => 'bar',
			        'options' => array(
						'palette1' => __( 'Palette 1', $text_domain ),
			            'palette2' => __( 'Palette 2', $text_domain ),
			            'palette3' => __( 'Palette 3', $text_domain ),
						'palette4' => __( 'Palette 4', $text_domain ),
						'palette4' => __( 'Palette 4', $text_domain ),
			            'palette5' => __( 'Palette 5', $text_domain ),
			            'palette6' => __( 'Palette 6', $text_domain ),
						'palette7' => __( 'Palette 7', $text_domain ),
						'palette8' => __( 'Palette 8', $text_domain ),
			            'palette9' => __( 'Palette 9', $text_domain ),
			            'palette10' => __( 'Palette 10', $text_domain )
					),
					'state_handler' => array(
						'uu_donut_chart_color_options_radio[color_theme]' => array('show'),
						'uu_donut_chart_color_options_radio[monochrome]' => array('hide'),
					)
				),
				
				//monochrome color picker
				'uu_donut_chart_monochrome_color_picker' => array(
					'type' => 'color',
					'label' => __( 'Choose a color', $text_domain ),
					'default' => '#CC0000',
					'state_handler' => array(
						'uu_donut_chart_color_options_radio[color_theme]' => array('hide'),
						'uu_donut_chart_color_options_radio[monochrome]' => array('show'),
					)
				),

				//monochrome shade
				'uu_donut_chart_shade_to_dark_or_light' => array(
					'type' => 'radio',
					'label' => __( 'Shade monochrome color to dark or light?', $text_domain ),
					'default' => 'light',
					'options' => array(
						'dark' => __( 'Dark', $text_domain ),
						'light' => __( 'Light', $text_domain )
					),
					'state_handler' => array(
						'uu_donut_chart_color_options_radio[color_theme]' => array('hide'),
						'uu_donut_chart_color_options_radio[monochrome]' => array('show'),
					)
				),

				//Slider
				'uu_donut_chart_height' => array(
					'type' => 'slider',
					'label' => __( 'Donut Chart Height', $text_domain ),
					'default' => 400,
					'min' => 300,
					'max' => 600,
					'integer' => true
				),


				//display tool bar
				'uu_donut_chart_display_tool_bar' => array(
					'type' => 'radio',
					'label' => __( 'Display Tool Bar?', $text_domain ),
					'default' => 'true',
					'options' => array(
						'true' => __( 'Yes', $text_domain ),
						'false' => __( 'No', $text_domain )
					)
				),

				//display tooltip on hover
				'uu_donut_chart_display_tip_hover' => array(
					'type' => 'radio',
					'label' => __( 'Display Tool Tip on Hover?', $text_domain ),
					'default' => 'true',
					'options' => array(
						'true' => __( 'Yes', $text_domain ),
						'false' => __( 'No', $text_domain )
					)
				),

				'uu_donut_chart_show_labels_on_hover' => array(
					'type' => 'radio',
					'label' => __( 'Show Labels in Center of Donut on Hover?', $text_domain ),
					'default' => 'true',
					'options' => array(
						'true' => __( 'Yes', $text_domain ),
						'false' => __( 'No', $text_domain )
					),
					'state_handler' => array(
						'uu_donut_chart_pie_or_donut[pie]' => array('hide'),
						'uu_donut_chart_pie_or_donut[donut]' => array('show'),
					)
				),

				//Slider
				'uu_donut_chart_thickness' => array(
					'type' => 'slider',
					'label' => __( 'Donut Chart Thickness - Note: higher number equals a thinner line', $text_domain ),
					'default' => 35,
					'min' => 20,
					'max' => 80,
					'integer' => false
				),

				//Labels
				'data_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Pie / Donut Chart Data' , $text_domain ),
					'item_name'  => __( 'Data', $text_domain ),
			        'fields' => array(
					    'uuDonutChartLabels' => array(
							'label' => __( 'Data Label', $text_domain ),
					        'type' => 'text',
					        'default' => '',
						),
						'uuDonutChartData' => array(
							'label' => __( 'Data Value', $text_domain ),
					        'type' => 'text',
							'default' => '',
					    ),
			        )
				),
			),
			plugin_dir_path(__FILE__)
		);

		add_action('wp_footer', function(){
		    if($this->widgets_code) {
		        $js = [];
		        foreach($this->widgets_code as $instance) {
                    $js[] = [
                        'donutChartData'           => $instance['data_repeater'],
						'donutPieOrDonut'          => $instance['uu_donut_chart_pie_or_donut'],
						'donutChartOptions'        => $instance['uu_donut_chart_color_options_radio'],
						'donutChartColorTheme'     => $instance['uu_donut_chart_color_theme'],
						'donutChartMonochrome'     => $instance['uu_donut_chart_monochrome_color_picker'],
						'donutChartDarkLight'      => $instance['uu_donut_chart_shade_to_dark_or_light'],
						'donutChartDisplayToolbar' => $instance['uu_donut_chart_display_tool_bar'], 
						'donutChartDisplayTooltip' => $instance['uu_donut_chart_display_tip_hover'], 
						'donutChartShowLabels'     => $instance['uu_donut_chart_show_labels_on_hover'],
						'donutChartHeight'         => $instance['uu_donut_chart_height'],
						'donutChartThickness'         => $instance['uu_donut_chart_thickness'],
						'widgetId'                 => 'uu-donut-chart-' . $instance["_sow_form_id"]
                    ];
                }
		        echo '<script>var uuDonutChartJs = '.json_encode($js).'</script>';
            }
        });

	}//end construct


	function get_template_name($instance) {
		add_action('siteorigin_widgets_after_widget_uu-donut-chart-widget', function($instance){
	        $this->widgets_code[$instance['_sow_form_id']] = $instance;
        },10,2);
		return 'uu-donut-chart-widget-template';
	}


	function initialize() {
		$this->register_frontend_scripts(
	        array(
	            array( 'apex-chart-js',
	            	'https://cdn.jsdelivr.net/npm/apexcharts',
	            	array( 'jquery' ),
	            	 '3.20.0',
	            	 false
	            	)
	        )
	    );
		$this->register_frontend_scripts(
	        array(
	            array( 'uu-donut-chart-widget-scripts',
	            	plugin_dir_url(__FILE__) . 'js/uu-donut-chart-widget.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            )
	        )
	    );
		$this->register_frontend_styles(
			array(
				array(
					'uu-donut-chart-widget-styles',
					plugin_dir_url(__FILE__) . 'css/uu-donut-chart-widget.css',
					array(),
					'1.0'
				),
			)
		);

	}

}

siteorigin_widget_register('uu-donut-chart-widget', __FILE__, 'uu_donut_chart_Widget');

