<?php

/*
Widget Name: U of U Line Chart Widget
Description: Display an informational chart on any page.
Author: Brian Thurber
Author URI: https://umc.utah.edu
*/

class UU_Line_Chart_Widget extends SiteOrigin_Widget {

	private $widgets_code = [];
	
	function __construct() {
		$text_domain = 'uu-line-chart-widget-text-domain';
		parent::__construct(
			'uu-line-chart-widget',
			__('U of U Line Chart Widget', $text_domain),
			array(
				'description' => __('Display a line chart on any page.', $text_domain),
			),
			array(

			),
			//form options
			array(
				'uu_line_chart_color_options_radio' => array(
					'type' => 'radio',
					'label' => __( 'Complete color theme or monochrome based on single color?', $text_domain ),
					'default' => 'monochrome',
					'options' => array(
						'color_theme' => __( 'Color Theme', $text_domain ),
						'monochrome' => __( 'Monochrome', $text_domain )
					),
					'state_emitter' => array(
						'callback' => 'select',
						'args' => array( 'uu_line_chart_color_options_radio' )
					),
				),

				'uu_line_chart_color_theme' => array(
			        'type' => 'select',
			        'label' => __( 'Chart Type', $text_domain ),
					'default' => 'bar',
			        'options' => array(
						'palette1' => __( 'Palette 1', $text_domain ),
			            'palette2' => __( 'Palette 2', $text_domain ),
			            'palette3' => __( 'Palette 3', $text_domain ),
						'palette4' => __( 'Palette 4', $text_domain ),
						'palette4' => __( 'Palette 4', $text_domain ),
			            'palette5' => __( 'Palette 5', $text_domain ),
			            'palette6' => __( 'Palette 6', $text_domain ),
						'palette7' => __( 'Palette 7', $text_domain ),
						'palette8' => __( 'Palette 8', $text_domain ),
			            'palette9' => __( 'Palette 9', $text_domain ),
			            'palette10' => __( 'Palette 10', $text_domain )
					),
					'state_handler' => array(
						'uu_line_chart_color_options_radio[color_theme]' => array('show'),
						'uu_line_chart_color_options_radio[monochrome]' => array('hide'),
					)
				),
				
				//monochrome color picker
				'uu_line_chart_monochrome_color_picker' => array(
					'type' => 'color',
					'label' => __( 'Choose a color', $text_domain ),
					'default' => '#c00000',
					'state_handler' => array(
						'uu_line_chart_color_options_radio[color_theme]' => array('hide'),
						'uu_line_chart_color_options_radio[monochrome]' => array('show'),
					)
				),

				//monochrome shade
				'uu_line_chart_shade_to_dark_or_light' => array(
					'type' => 'radio',
					'label' => __( 'Shade monochrome color to dark or light?', $text_domain ),
					'default' => 'light',
					'options' => array(
						'dark' => __( 'Dark', $text_domain ),
						'light' => __( 'Light', $text_domain )
					),
					'state_handler' => array(
						'uu_line_chart_color_options_radio[color_theme]' => array('hide'),
						'uu_line_chart_color_options_radio[monochrome]' => array('show'),
					)
				),

				//Slider
				'uu_line_chart_height' => array(
					'type' => 'slider',
					'label' => __( 'Line Chart Height', $text_domain ),
					'default' => 400,
					'min' => 300,
					'max' => 600,
					'integer' => true
				),


				//line Type
				'uu_line_chart_line_type' => array(
					'type' => 'select',
					'label' => __( 'Line Type', $text_domain ),
					'default' => 'straight',
					'options' => array(
						'smooth' => __( 'Smooth', $text_domain ),
						'straight' => __( 'Straight', $text_domain ),
						'stepline' => __( 'Stepline', $text_domain ),
					)
				),

				//display tool bar
				'uu_line_chart_display_tool_bar' => array(
					'type' => 'radio',
					'label' => __( 'Display Tool Bar?', $text_domain ),
					'default' => 'true',
					'options' => array(
						'true' => __( 'Yes', $text_domain ),
						'false' => __( 'No', $text_domain )
					)
				),

				//display tooltip on hover
				'uu_line_chart_display_tip_hover' => array(
					'type' => 'radio',
					'label' => __( 'Display Tool Tip on Hover?', $text_domain ),
					'default' => 'true',
					'options' => array(
						'true' => __( 'Yes', $text_domain ),
						'false' => __( 'No', $text_domain )
					)
				),

				//Labels
				'label_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Labels - Horizontal Values' , $text_domain ),
					'item_name'  => __( 'Label', $text_domain ),
			        'fields' => array(
					    'uuLineChartLabel' => array(
					        'type' => 'text',
					        'default' => '',
					    ),
			        )
				),

				//Data Sets
				'dataset_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Dataset - Vertical Values' , $text_domain ),
					'item_name'  => __( 'Dataset', $text_domain ),
			        'fields' => array(
					    'uuLineChartDatasetData' => array(
							'label' => __( 'Enter Data Values - Must be comma separated and have equal number of values to number of labels' , $text_domain ),
					        'type' => 'textarea',
					        'default' => '',
					        'rows' => 3,
						),
						'uuLineChartDatasetLabel' => array(
							'label' => __( 'Dataset Label - Will be displayed invertical column' , $text_domain ),
					        'type' => 'text',
					        'default' => '',
						),

			        )
				),

			),
			plugin_dir_path(__FILE__)
		);

		add_action('wp_footer', function(){
		    if($this->widgets_code) {
		        $js = [];
		        foreach($this->widgets_code as $instance) {
                    $js[] = [
						'lineChartLabels'         => $instance['label_repeater'],
						'lineChartDataset'        => $instance['dataset_repeater'],
						'lineChartOptions'        => $instance['uu_line_chart_color_options_radio'],
						'lineChartColorTheme'     => $instance['uu_line_chart_color_theme'],
						'lineChartMonochrome'     => $instance['uu_line_chart_monochrome_color_picker'],
						'lineChartDarkLight'      => $instance['uu_line_chart_shade_to_dark_or_light'],
						'lineChartLineType'       => $instance['uu_line_chart_line_type'], 
						'lineChartDisplayToolbar' => $instance['uu_line_chart_display_tool_bar'], 
						'lineChartDisplayTooltip' => $instance['uu_line_chart_display_tip_hover'],
						'lineChartHeight'         => $instance['uu_line_chart_height'],
						'widgetId'                => 'uu-line-chart-' . $instance["_sow_form_id"]
                    ];
                }
		        echo '<script>var uuLineChartJs = '.json_encode($js).'</script>';
            }
		});

	}// end construct


	function get_template_name($instance) {
		add_action('siteorigin_widgets_after_widget_uu-line-chart-widget', function($instance){
	        $this->widgets_code[$instance['_sow_form_id']] = $instance;
        },10,2);
		return 'uu-line-chart-widget-template';
	}


	function initialize() {
		$this->register_frontend_scripts(
	        array(
	            array( 'apex-chart-js',
	            	'https://cdn.jsdelivr.net/npm/apexcharts',
	            	array( 'jquery' ),
	            	 '3.20.0',
	            	 false
	            	)
	        )
	    );
		$this->register_frontend_scripts(
	        array(
	            array( 'uu-line-chart-widget-scripts',
	            	plugin_dir_url(__FILE__) . 'js/uu-line-chart-widget.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            )
	        )
	    );
		$this->register_frontend_styles(
			array(
				array(
					'uu-line-chart-widget-styles',
					plugin_dir_url(__FILE__) . 'css/uu-line-chart-widget.css',
					array(),
					'1.0'
				),
			)
		);

	}

}

siteorigin_widget_register('uu-line-chart-widget', __FILE__, 'UU_Line_Chart_Widget');

