<?php
/*
Widget Name: U of U Marquee Widget
Description: Display a marquee on any page.
Author: Brian Thurber, James Tombs
Author URI: https://umc.utah.edu
*/

class U_Of_U_Marquee_Widget extends SiteOrigin_Widget {


	function __construct() {

		parent::__construct(
			'uu-marquee-widget',
			__('U of U Marquee Widget', 'uu-marquee-widget-text-domain'),
			array(
				'description' => __('Display a slider marquee on your site.', 'uu-marquee-widget-text-domain'),
			),
			array(

			),
			//form options
			array(
					//Marquee Speed
					'uu_marquee_speed' => array(
				        'type' => 'slider',
				        'label' => __( 'Marquee Speed - Time between movements', 'uu-marquee-widget-text-domain' ),
				        'default' => 5,
				        'min' => 1,
				        'max' => 10,
				        'integer' => true
				    ),
				    //Easing Speed
					'uu_marquee_easing_speed' => array(
				        'type' => 'slider',
				        'label' => __( 'Easing Speed - Speed of the movements', 'uu-marquee-widget-text-domain' ),
				        'default' => 5,
				        'min' => 1,
				        'max' => 10,
				        'integer' => true
				    ),
				    //Height
					'uu_marquee_height' => array(
				        'type' => 'slider',
				        'label' => __( 'Marquee Height in pixels', 'uu-marquee-widget-text-domain' ),
				        'default' => 600,
				        'min' => 300,
				        'max' => 900,
								'step' => 50,
				        'integer' => true
				    ),
				    //full screen
				    'uu_marquee_full_screen_bool' => array(
				        'type' => 'checkbox',
				        'label' => __( 'Enable Full Height Marquee - Overrides marquee height', 'uu-marquee-widget-text-domain' ),
				        'default' => false
				    ),
				    //parallax (dead until 2mz can fix)
				    'uu_marquee_parallax_bool' => array(
				        'type' => 'checkbox',
				        'label' => __( 'Enable Parallax Scrolling', 'uu-marquee-widget-text-domain' ),
				        'default' => false
				    ),
				    'marquee_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Marquee Slides' , 'uu-marquee-widget-text-domain' ),
			        'item_name'  => __( 'Slide', 'siteorigin-widgets' ),
			        'fields' => array(
			        	//Background image
			          'uu_marquee_image' => array(
					        'type' => 'media',
					        'choose' => __( 'Choose image', 'uu-marquee-widget-text-domain' ),
					        'update' => __( 'Set image', 'uu-marquee-widget-text-domain' ),
					        'library' => 'image',
					        'fallback' => true
					    	),
							  //title
							  'uu_marquee_title' => array(
									'type' => 'text',
									'label' => __('Title', 'uu-marquee-widget-text-domain')
								),
								//description
							    'uu_marquee_description' => array(
									'type' => 'textarea',
									'label' => __('Description', 'uu-marquee-widget-text-domain'),
							        'default' => '',
							        'rows' => 3,
							    ),
							  //button text
							  'uu_marquee_button_text' => array(
									'type' => 'text',
									'label' => __('Button Text', 'uu-marquee-widget-text-domain'),
								),
								//button url
								'uu_marquee_button_url' => array(
							        'type' => 'link',
							        'label' => __('Link URL for this image', 'uu-marquee-widget-text-domain'),
							  ),
						    //open link in new tab
						    'uu_marquee_new_tab_bool' => array(
						        'type' => 'checkbox',
						        'label' => __( 'Open link in new tab', 'uu-marquee-widget-text-domain' ),
						        'default' => false
						    ),
						    //Logo image
				       	'uu_marquee_logo_image' => array(
						        'type' => 'media',
						        'choose' => __( 'Choose Logo Image - transparent PNG recommended (300px wide)', 'uu-marquee-widget-text-domain' ),
						        'update' => __( 'Set image', 'uu-marquee-widget-text-domain' ),
						        'library' => 'image',
						        'fallback' => true
						    ),
							// Justification
						    'uu_marquee_justification' => array(
								'type' => 'select',
								'label' => __( 'Text Justification', 'uu-marquee-widget-text-domain' ),
								'default' => 'center',
								'options' => array(
										'center' => __( 'Center', 'uu-marquee-widget-text-domain' ),
										'left' => __( 'Left', 'uu-marquee-widget-text-domain' ),
										'right' => __( 'Right', 'uu-marquee-widget-text-domain' )
									)
								),
								// Background Image Justification
								'uu_marquee_bg_img_justification' => array(
									'type' => 'select',
									'label' => __( 'Background Image Justification', 'uu-marquee-widget-text-domain' ),
									'default' => 'center',
									'options' => array(
											'top' => __( 'Top', 'uu-marquee-widget-text-domain' ),
											'center' => __( 'Center', 'uu-marquee-widget-text-domain' ),
											'bottom' => __( 'Bottom', 'uu-marquee-widget-text-domain' )
										)
									),
								// Color Theme
								'uu_marquee_color_theme' => array(
									'type' => 'select',
									'label' => __( 'Color Theme', 'uu-marquee-widget-text-domain' ),
									'default' => 'light_theme',
									'options' => array(
											'u-of-u-marquee-dark-theme' => __( 'Dark Theme', 'uu-marquee-widget-text-domain' ),
											'u-of-u-marquee-light-theme' => __( 'Light Theme', 'uu-marquee-widget-text-domain' )
									)
								),
								// Gradient Start Color
								'uu_marquee_start_color' => array(
									'type' => 'color',
									'label' => __( 'Gradient Starting Color', 'uu-marquee-widget-text-domain' ),
									'default' => '#CC0000'
								),
								// Gradient End Color
								'uu_marquee_end_color' => array(
									'type' => 'color',
									'label' => __( 'Gradient Ending Color', 'uu-marquee-widget-text-domain' ),
									'default' => '#990000'
								),
								// Gradient Opacity
								'uu_marquee_gradient_opacity' => array(
						        'type' => 'slider',
						        'label' => __( 'Gradient Opacity', 'uu-marquee-widget-text-domain' ),
						        'default' => 0,
						        'min' => 0,
						        'max' => 10,
						        'integer' => true
						    	),
								// Gradient Direction
								'uu_marquee_gradient_direction' => array(
										'type' => 'select',
										'label' => __( 'Gradient Direction', 'uu-marquee-widget-text-domain' ),
										'default' => 'top',
										'options' => array(
												'top' => __( 'Top', 'uu-marquee-widget-text-domain' ),
												'right' => __( 'Right', 'uu-marquee-widget-text-domain' ),
												'bottom' => __( 'Bottom', 'uu-marquee-widget-text-domain' ),
												'left' => __( 'Left', 'uu-marquee-widget-text-domain' ),
										)
								),
			        )
			   )
			),
			plugin_dir_path(__FILE__)
		);

	}


	function get_template_name($instance) {
		return 'uu-marquee-widget-template';
	}


	function initialize() {
		$this->register_frontend_scripts(
	        array(
	            array( 'owl-js',
	            	plugin_dir_url(__FILE__) . 'js/vendor/owl/owl.carousel.min.js',
	            	array( 'jquery' ),
	            	 '2.3.4',
	            	 true
	            	)
	        )
	    );
		$this->register_frontend_scripts(
	        array(
	            array( 'u-of-u-marquee-widget-js',
	            	plugin_dir_url(__FILE__) . 'js/uu-marquee-widget.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            	)
	        )
	    );
	    $this->register_frontend_styles(
			array(
				array(
					'owl-css',
					plugin_dir_url(__FILE__) . 'css/vendor/owl/owl.carousel.min.css',
					array(),
					'2.3.4'
				),
			)
		);
		$this->register_frontend_styles(
			array(
				array(
					'u-of-u-marquee-widget-css',
					plugin_dir_url(__FILE__) . 'css/uu-marquee-widget.css',
					array(),
					'1.0'
				),
			)
		);

	}

}

siteorigin_widget_register('uu-marquee-widget', __FILE__, 'U_Of_U_Marquee_Widget');
