<?php

/*
Widget Name: U of U Photo Gallery Widget
Description: Display a simple photo gallery on any page.
Author: Brian Thurber
Author URI: https://umc.utah.edu
*/

class UU_Photo_Gallery_Widget extends SiteOrigin_Widget {


	function __construct() {

		parent::__construct(
			'uu-photo-gallery-widget',
			__('U of U Photo Gallery Widget', 'uu-photo-gallery-widget-text-domain'),
			array(
				'description' => __('Display a carousel with an image and a wysiwyg editor side by side.', 'uu-photo-gallery-widget-text-domain'),
			),
			array(

			),
			//form options
			array(

				'layout_type_radio' => array(
			        'type' => 'radio',
			        'label' => __( 'Layout Type', 'uu-photo-gallery-widget-text-domain' ),
			        'default' => 'uu_gallery_thumbnails',
			        'options' => array(
			            'uu_gallery_thumbnails' => __( 'Thumbnail Layout', 'uu-photo-gallery-widget-text-domain' ),
			            'uu_gallery_slider' => __( 'Slider Layout', 'uu-photo-gallery-widget-text-domain' )
			        )
			    ),
			    'auto_scroll_checkbox' => array(
			        'type' => 'checkbox',
			        'label' => __( 'Allow auto scroll on slider view (does not effect thumbnail layout)', 'uu-photo-gallery-widget-text-domain' ),
			        'default' => false
			    ),
				'a_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Photo Gallery' , 'uu-photo-gallery-widget-text-domain' ),
			        'item_name'  => __( 'Image', 'siteorigin-widgets' ),
			        'fields' => array(
			            'uu_photo_gallery_image' => array(
					        'type' => 'media',
					        'choose' => __( 'Choose image', 'uu-photo-gallery-widget-text-domain' ),
					        'update' => __( 'Set image', 'uu-photo-gallery-widget-text-domain' ),
					        'library' => 'image',
					        'fallback' => true
					    ),
					    'uu_photo_gallery_caption' => array(
					        'type' => 'textarea',
					        'default' => '',
					        'rows' => 10,
					    ),
			        )
			    )
			),
			plugin_dir_path(__FILE__)
		);

	}


	function get_template_name($instance) {
		return 'uu-photo-gallery-widget-template';
	}

	function get_template_variables( $instance, $args ) {

	    // Ensure that the repeater is available and not empty.
	    $joined_text = "";

	    if ( ! empty( $instance['a_repeater'] ) ) {

	        $repeater_items = $instance['a_repeater'];

	        foreach( $repeater_items as $index => $repeater_item ) {

	            $text_from_repeater_item_title = $repeater_item['uu_photo_gallery_image'];

	            //echo $text_from_repeater_item_title;

	    		/// appending string
	            $joined_text .= $text_from_repeater_item_title;

	            $repeater_item_editor = $repeater_item['uu_photo_gallery_caption'];
	        }

	    }

	    return array(
	        'joined_text' => !empty( $joined_text ) ? $joined_text : 'No data was captured'
	    );
	}

	function initialize() {
		$this->register_frontend_scripts(
	        array(
	            array( 'owl-js',
	            	plugin_dir_url(__FILE__) . 'js/vendor/owl/owl.carousel.min.js',
	            	array( 'jquery' ),
	            	 '2.3.4',
	            	 true
	            	)
	        )
	    );
	    $this->register_frontend_styles(
			array(
				array(
					'owl-css',
					plugin_dir_url(__FILE__) . 'css/vendor/owl/owl.carousel.min.css',
					array(),
					'2.3.4'
				),
			)
		);
		$this->register_frontend_scripts(
	        array(
	            array( 'uu-photo-gallery-widget-scripts',
	            	plugin_dir_url(__FILE__) . '/js/uu-photo-gallery-widget.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            )
	        )
	    );
		$this->register_frontend_styles(
			array(
				array(
					'uu-photo-gallery-widget-styles',
					plugin_dir_url(__FILE__) . '/css/uu-photo-gallery-widget.css',
					array(),
					'1.0'
				),
			)
		);

	}

}

siteorigin_widget_register('uu-photo-gallery-widget', __FILE__, 'UU_Photo_Gallery_Widget');
