<?php
/*
Widget Name: U of U Post Loop Widget
Description: Custom Post Loop Templates for The University of Utah
Author: James Tombs
Author URI: digital.utah.edu
Widget URI: digital.utah.edu
*/

class UU_Post_Loop_Widget extends SiteOrigin_Widget {

  // CONSTRUCT FIELDS
  function __construct() {

    // CALL PARENT WITH ARGS
		parent::__construct(

      // WIDGET ID, NAME, OPTIONS, AND FIELDS
      // ID
      'uu-post-loop-widget',
      // NAME
			__('U of U Post Loop Widget', 'uu-post-loop-widget-text-domain'),
      // WIDGET OPTIONS
			array(
				'description' => __('Dislpay posts within post loop templates.', 'uu-post-loop-widget-text-domain'),
			),
      // CONTROL OPTIONS
			array(

			),
			//FIELDS (FORM OPTIONS)
			array(
        // TYPE:INTERNAL OR EXTERNAL
        'uu_post_loop_type' => array(
          'type' => 'select',
          'label' => __( 'Internal or External', 'uu-post-loop-widget-text-domain' ),
          'default' => 'uu-post-loop-type-internal',
          'options' => array(
            'uu-post-loop-type-internal' => __( 'Internal', 'uu-post-loop-widget-text-domain' ),
            'uu-post-loop-type-external' => __( 'External', 'uu-post-loop-widget-text-domain' ),
          ),
          'state_emitter' => array(
            'callback' => 'select',
            'args' => array( 'uu_post_loop_type' )
          ),
        ),
        // LAYOUT
        'uu_post_loop_layout' => array(
          'type' => 'select',
          'label' => __( 'Choose a Layout', 'uu-post-loop-widget-text-domain' ),
          'default' => 'uu-post-loop-layout-1',
          'options' => array(
            'uu-post-loop-layout-1' => __( 'Layout 1 - Three Posts Carousel ', 'uu-post-loop-widget-text-domain' ),
            'uu-post-loop-layout-2' => __( 'Layout 2 - Four Posts', 'uu-post-loop-widget-text-domain' ),
            'uu-post-loop-layout-3' => __( 'Layout 3 - Two Small Posts Carousel', 'uu-post-loop-widget-text-domain' ),
            'uu-post-loop-layout-4' => __( 'Layout 4 - One Post Carousel', 'uu-post-loop-widget-text-domain' ),
            'uu-post-loop-layout-5' => __( 'Layout 5 - 5 Posts in a List', 'uu-post-loop-widget-text-domain' )
          )
        ),
        // EXERNAL URL/ENDPOINT
        'uu_post_loop_endpoint' => array(
          'type' => 'text',
          'label' => __('URL Endpoint', 'uu-post-loop-widget-text-domain'),
          'default' => '',
          'description' => 'https://attheu.utah.edu/',
          'state_handler' => array(
              'uu_post_loop_type[uu-post-loop-type-internal]' => array('hide'),
              'uu_post_loop_type[uu-post-loop-type-external]' => array('show'),
          ),
        ),
        // POST TYPES
        'uu_post_loop_post_type' => array(
          'type' => 'text',
          'label' => __('Post Types', 'uu-post-loop-widget-text-domain'),
          'default' => 'post',
          'description' => 'Post Type names, seperated by commas. (post, my-cpt). Also "posts" not "post" on external feeds',
        ),
        // POSTS PER PAGE
        'uu_post_loop_per_page' => array(
          'type' => 'text',
          'label' => __('Posts Per Page', 'uu-post-loop-widget-text-domain'),
          'default' => '10',
        ),
        // CATEGORY
        'uu_post_loop_categories' => array(
          'type' => 'text',
          'label' => __('Categories', 'uu-post-loop-widget-text-domain'),
          'default' => '',
          'description' => 'Category slug names, seperated by commas. (news, my-category-slug)',
        ),
        // TAGS
        'uu_post_loop_tags' => array(
          'type' => 'text',
          'label' => __('Tags', 'uu-post-loop-widget-text-domain'),
          'default' => '',
          'description' => 'Tag slug names, seperated by commas. (president, university)',
        ),

        // CPT POST LINK
        'uu_post_loop_cpt_url' => array(
          'type' => 'text',
          'label' => __('Custom Post Type URL Link', 'uu-post-loop-widget-text-domain'),
          'default' => '',
          'description' => 'Override Post Link with Metabox URL Field (use Metabox Field ID)',
        ),
			),
      // BASE FOLDER PATH
			plugin_dir_path(__FILE__)
		);

	}

  // GET TEMPLATE NAME
  function get_template_name($instance) {
      return 'uu-post-loop-widget';
  }



  // INIT SCRIPTS & STYLES
  function initialize() {
    $this->register_frontend_scripts(
      array(
          array( 'uu-post-loop-widget-owl-scripts',
          	plugin_dir_url(__FILE__) . '/js/owl.carousel.min.js',
          	array( 'jquery' ),
          	 '1.0',
          	 true
          ),
          array( 'uu-post-loop-widget-scripts',
          	plugin_dir_url(__FILE__) . '/js/uu-post-loop-widget.js',
          	array( 'jquery' ),
          	 time(),
          	 true
          )
      )
    );
		$this->register_frontend_styles(
			array(
				array(
					'uu-post-loop-widget-styles',
					plugin_dir_url(__FILE__) . '/css/uu-post-loop-widget.css',
					array(),
					time()
				),
			)
		);
	}
}

siteorigin_widget_register('uu-post-loop-widget', __FILE__, 'UU_Post_Loop_Widget');
