<?php

/*
Widget Name: U of U Split Section Carousel Widget
Description: Display a carousel with an image and a wysiwyg editor side by side.
Author: Brian Thurber, James Tombs
Author URI: https://umc.utah.edu
*/

class UU_Split_Section_Carousel_Widget extends SiteOrigin_Widget {


	function __construct() {

		parent::__construct(
			'uu-split-section-carousel-widget',
			__('U of U Split Section Carousel Widget', 'uu-split-section-carousel-widget-text-domain'),
			array(
				'description' => __('Display a carousel with an image and a wysiwyg editor side by side.', 'uu-split-section-carousel-widget-text-domain'),
			),
			array(

			),
			//form options
			array(
				    'a_repeater' => array(
			        'type' => 'repeater',
			        'label' => __( 'Carousel Slides' , 'widget-form-fields-text-domain' ),
			        'item_name'  => __( 'Slide', 'siteorigin-widgets' ),
			        'fields' => array(
			            'uu_sscw_image' => array(
					        'type' => 'media',
					        'choose' => __( 'Choose image', 'widget-form-fields-text-domain' ),
					        'update' => __( 'Set image', 'widget-form-fields-text-domain' ),
					        'library' => 'image',
					        'fallback' => true
					    ),
					    'uu_sscw_editor' => array(
					        'type' => 'tinymce',
					        'default' => '',
					        'rows' => 10,
					        'default_editor' => 'html',
					        'button_filters' => array(
					            'mce_buttons' => array( $this, 'filter_mce_buttons' ),
					            'mce_buttons_2' => array( $this, 'filter_mce_buttons_2' ),
					            'mce_buttons_3' => array( $this, 'filter_mce_buttons_3' ),
					            'mce_buttons_4' => array( $this, 'filter_mce_buttons_5' ),
					            'quicktags_settings' => array( $this, 'filter_quicktags_settings' ),
					        ),
					    ),
						'uu_sscw_alignment' => array(
							'type' => 'select',
							'label' => __( 'Alignment', 'widget-form-fields-text-domain' ),
							'default' => 'left',
							'options' => array(
									'left' => __( 'Image Left', 'widget-form-fields-text-domain' ),
									'right' => __( 'Image Right', 'widget-form-fields-text-domain' )
							)
					    ),
						'uu_sscw_bg_color' => array(
					        'type' => 'color',
					        'label' => __( 'Background Color', 'widget-form-fields-text-domain' ),
					        'default' => '#ffffff'
					    ),
						'uu_sscw_font_color' => array(
					        'type' => 'color',
					        'label' => __( 'Font Color', 'widget-form-fields-text-domain' ),
					        'default' => '#000000'
					    )

			        )
			    )
			),
			plugin_dir_path(__FILE__)
		);

	}


	function get_template_name($instance) {
		return 'uu-split-section-carousel-widget-template';
	}

	function get_template_variables( $instance, $args ) {

	    // Ensure that the repeater is available and not empty.
	    $joined_text = "";

	    if ( ! empty( $instance['a_repeater'] ) ) {

	        $repeater_items = $instance['a_repeater'];

	        foreach( $repeater_items as $index => $repeater_item ) {

	            $text_from_repeater_item_image = $repeater_item['uu_sscw_image'];

	    		/// appending string
	            $joined_text .= $text_from_repeater_item_image;

	            $boolean_from_repeater_item_editor = $repeater_item['uu_sscw_editor'];

				$option_from_repeater_item_uu_sscw_alignment = $repeater_item['uu_sscw_alignment'];

				$color_from_repeater_item_uu_sscw_bg_color = $repeater_item['uu_sscw_bg_color'];

				$color_from_repeater_item_uu_sscw_font_color = $repeater_item['uu_sscw_font_color'];

	        }

	    }

	    return array(
	        'joined_text' => !empty( $joined_text ) ? $joined_text : 'No data was captured'
	    );
	}

	function initialize() {
		$this->register_frontend_scripts(
	        array(
	            array( 'uu-split-section-carousel-widget-owl-scripts',
	            	plugin_dir_url(__FILE__) . '/js/owl.carousel.min.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            ),
	            array( 'uu-split-section-carousel-widget-scripts',
	            	plugin_dir_url(__FILE__) . '/js/uu-split-section-carousel-widget.js',
	            	array( 'jquery' ),
	            	 '1.0',
	            	 true
	            )
	        )
	    );
		$this->register_frontend_styles(
			array(
				array(
					'uu-split-section-carousel-widget-styles',
					plugin_dir_url(__FILE__) . '/css/uu-split-section-carousel-widget.css',
					array(),
					'1.0'
				),
			)
		);
	}

}

siteorigin_widget_register('uu-split-section-carousel-widget', __FILE__, 'UU_Split_Section_Carousel_Widget');
